# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class PositionClose(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {'time': 'float', 'contract': 'str', 'side': 'str', 'pnl': 'str', 'text': 'str'}

    attribute_map = {'time': 'time', 'contract': 'contract', 'side': 'side', 'pnl': 'pnl', 'text': 'text'}

    def __init__(
        self, time=None, contract=None, side=None, pnl=None, text=None, local_vars_configuration=None
    ):  # noqa: E501
        # type: (float, str, str, str, str, Configuration) -> None
        """PositionClose - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._time = None
        self._contract = None
        self._side = None
        self._pnl = None
        self._text = None
        self.discriminator = None

        if time is not None:
            self.time = time
        if contract is not None:
            self.contract = contract
        if side is not None:
            self.side = side
        if pnl is not None:
            self.pnl = pnl
        if text is not None:
            self.text = text

    @property
    def time(self):
        """Gets the time of this PositionClose.  # noqa: E501

        Position close time  # noqa: E501

        :return: The time of this PositionClose.  # noqa: E501
        :rtype: float
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this PositionClose.

        Position close time  # noqa: E501

        :param time: The time of this PositionClose.  # noqa: E501
        :type: float
        """

        self._time = time

    @property
    def contract(self):
        """Gets the contract of this PositionClose.  # noqa: E501

        Futures contract  # noqa: E501

        :return: The contract of this PositionClose.  # noqa: E501
        :rtype: str
        """
        return self._contract

    @contract.setter
    def contract(self, contract):
        """Sets the contract of this PositionClose.

        Futures contract  # noqa: E501

        :param contract: The contract of this PositionClose.  # noqa: E501
        :type: str
        """

        self._contract = contract

    @property
    def side(self):
        """Gets the side of this PositionClose.  # noqa: E501

        Position side, long or short  # noqa: E501

        :return: The side of this PositionClose.  # noqa: E501
        :rtype: str
        """
        return self._side

    @side.setter
    def side(self, side):
        """Sets the side of this PositionClose.

        Position side, long or short  # noqa: E501

        :param side: The side of this PositionClose.  # noqa: E501
        :type: str
        """
        allowed_values = ["long", "short"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and side not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `side` ({0}), must be one of {1}".format(side, allowed_values)  # noqa: E501
            )

        self._side = side

    @property
    def pnl(self):
        """Gets the pnl of this PositionClose.  # noqa: E501

        PNL  # noqa: E501

        :return: The pnl of this PositionClose.  # noqa: E501
        :rtype: str
        """
        return self._pnl

    @pnl.setter
    def pnl(self, pnl):
        """Sets the pnl of this PositionClose.

        PNL  # noqa: E501

        :param pnl: The pnl of this PositionClose.  # noqa: E501
        :type: str
        """

        self._pnl = pnl

    @property
    def text(self):
        """Gets the text of this PositionClose.  # noqa: E501

        Text of close order  # noqa: E501

        :return: The text of this PositionClose.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this PositionClose.

        Text of close order  # noqa: E501

        :param text: The text of this PositionClose.  # noqa: E501
        :type: str
        """

        self._text = text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PositionClose):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PositionClose):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class FuturesLiquidate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'time': 'int',
        'contract': 'str',
        'leverage': 'str',
        'size': 'int',
        'margin': 'str',
        'entry_price': 'str',
        'liq_price': 'str',
        'mark_price': 'str',
        'order_id': 'int',
        'order_price': 'str',
        'fill_price': 'str',
        'left': 'int',
    }

    attribute_map = {
        'time': 'time',
        'contract': 'contract',
        'leverage': 'leverage',
        'size': 'size',
        'margin': 'margin',
        'entry_price': 'entry_price',
        'liq_price': 'liq_price',
        'mark_price': 'mark_price',
        'order_id': 'order_id',
        'order_price': 'order_price',
        'fill_price': 'fill_price',
        'left': 'left',
    }

    def __init__(
        self,
        time=None,
        contract=None,
        leverage=None,
        size=None,
        margin=None,
        entry_price=None,
        liq_price=None,
        mark_price=None,
        order_id=None,
        order_price=None,
        fill_price=None,
        left=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (int, str, str, int, str, str, str, str, int, str, str, int, Configuration) -> None
        """FuturesLiquidate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._time = None
        self._contract = None
        self._leverage = None
        self._size = None
        self._margin = None
        self._entry_price = None
        self._liq_price = None
        self._mark_price = None
        self._order_id = None
        self._order_price = None
        self._fill_price = None
        self._left = None
        self.discriminator = None

        if time is not None:
            self.time = time
        if contract is not None:
            self.contract = contract
        if leverage is not None:
            self.leverage = leverage
        if size is not None:
            self.size = size
        if margin is not None:
            self.margin = margin
        if entry_price is not None:
            self.entry_price = entry_price
        if liq_price is not None:
            self.liq_price = liq_price
        if mark_price is not None:
            self.mark_price = mark_price
        if order_id is not None:
            self.order_id = order_id
        if order_price is not None:
            self.order_price = order_price
        if fill_price is not None:
            self.fill_price = fill_price
        if left is not None:
            self.left = left

    @property
    def time(self):
        """Gets the time of this FuturesLiquidate.  # noqa: E501

        Liquidation time  # noqa: E501

        :return: The time of this FuturesLiquidate.  # noqa: E501
        :rtype: int
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this FuturesLiquidate.

        Liquidation time  # noqa: E501

        :param time: The time of this FuturesLiquidate.  # noqa: E501
        :type: int
        """

        self._time = time

    @property
    def contract(self):
        """Gets the contract of this FuturesLiquidate.  # noqa: E501

        Futures contract  # noqa: E501

        :return: The contract of this FuturesLiquidate.  # noqa: E501
        :rtype: str
        """
        return self._contract

    @contract.setter
    def contract(self, contract):
        """Sets the contract of this FuturesLiquidate.

        Futures contract  # noqa: E501

        :param contract: The contract of this FuturesLiquidate.  # noqa: E501
        :type: str
        """

        self._contract = contract

    @property
    def leverage(self):
        """Gets the leverage of this FuturesLiquidate.  # noqa: E501

        Position leverage. Not returned in public endpoints.  # noqa: E501

        :return: The leverage of this FuturesLiquidate.  # noqa: E501
        :rtype: str
        """
        return self._leverage

    @leverage.setter
    def leverage(self, leverage):
        """Sets the leverage of this FuturesLiquidate.

        Position leverage. Not returned in public endpoints.  # noqa: E501

        :param leverage: The leverage of this FuturesLiquidate.  # noqa: E501
        :type: str
        """

        self._leverage = leverage

    @property
    def size(self):
        """Gets the size of this FuturesLiquidate.  # noqa: E501

        Position size  # noqa: E501

        :return: The size of this FuturesLiquidate.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this FuturesLiquidate.

        Position size  # noqa: E501

        :param size: The size of this FuturesLiquidate.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def margin(self):
        """Gets the margin of this FuturesLiquidate.  # noqa: E501

        Position margin. Not returned in public endpoints.  # noqa: E501

        :return: The margin of this FuturesLiquidate.  # noqa: E501
        :rtype: str
        """
        return self._margin

    @margin.setter
    def margin(self, margin):
        """Sets the margin of this FuturesLiquidate.

        Position margin. Not returned in public endpoints.  # noqa: E501

        :param margin: The margin of this FuturesLiquidate.  # noqa: E501
        :type: str
        """

        self._margin = margin

    @property
    def entry_price(self):
        """Gets the entry_price of this FuturesLiquidate.  # noqa: E501

        Average entry price. Not returned in public endpoints.  # noqa: E501

        :return: The entry_price of this FuturesLiquidate.  # noqa: E501
        :rtype: str
        """
        return self._entry_price

    @entry_price.setter
    def entry_price(self, entry_price):
        """Sets the entry_price of this FuturesLiquidate.

        Average entry price. Not returned in public endpoints.  # noqa: E501

        :param entry_price: The entry_price of this FuturesLiquidate.  # noqa: E501
        :type: str
        """

        self._entry_price = entry_price

    @property
    def liq_price(self):
        """Gets the liq_price of this FuturesLiquidate.  # noqa: E501

        Liquidation price. Not returned in public endpoints.  # noqa: E501

        :return: The liq_price of this FuturesLiquidate.  # noqa: E501
        :rtype: str
        """
        return self._liq_price

    @liq_price.setter
    def liq_price(self, liq_price):
        """Sets the liq_price of this FuturesLiquidate.

        Liquidation price. Not returned in public endpoints.  # noqa: E501

        :param liq_price: The liq_price of this FuturesLiquidate.  # noqa: E501
        :type: str
        """

        self._liq_price = liq_price

    @property
    def mark_price(self):
        """Gets the mark_price of this FuturesLiquidate.  # noqa: E501

        Mark price. Not returned in public endpoints.  # noqa: E501

        :return: The mark_price of this FuturesLiquidate.  # noqa: E501
        :rtype: str
        """
        return self._mark_price

    @mark_price.setter
    def mark_price(self, mark_price):
        """Sets the mark_price of this FuturesLiquidate.

        Mark price. Not returned in public endpoints.  # noqa: E501

        :param mark_price: The mark_price of this FuturesLiquidate.  # noqa: E501
        :type: str
        """

        self._mark_price = mark_price

    @property
    def order_id(self):
        """Gets the order_id of this FuturesLiquidate.  # noqa: E501

        Liquidation order ID. Not returned in public endpoints.  # noqa: E501

        :return: The order_id of this FuturesLiquidate.  # noqa: E501
        :rtype: int
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this FuturesLiquidate.

        Liquidation order ID. Not returned in public endpoints.  # noqa: E501

        :param order_id: The order_id of this FuturesLiquidate.  # noqa: E501
        :type: int
        """

        self._order_id = order_id

    @property
    def order_price(self):
        """Gets the order_price of this FuturesLiquidate.  # noqa: E501

        Liquidation order price  # noqa: E501

        :return: The order_price of this FuturesLiquidate.  # noqa: E501
        :rtype: str
        """
        return self._order_price

    @order_price.setter
    def order_price(self, order_price):
        """Sets the order_price of this FuturesLiquidate.

        Liquidation order price  # noqa: E501

        :param order_price: The order_price of this FuturesLiquidate.  # noqa: E501
        :type: str
        """

        self._order_price = order_price

    @property
    def fill_price(self):
        """Gets the fill_price of this FuturesLiquidate.  # noqa: E501

        Liquidation order average taker price  # noqa: E501

        :return: The fill_price of this FuturesLiquidate.  # noqa: E501
        :rtype: str
        """
        return self._fill_price

    @fill_price.setter
    def fill_price(self, fill_price):
        """Sets the fill_price of this FuturesLiquidate.

        Liquidation order average taker price  # noqa: E501

        :param fill_price: The fill_price of this FuturesLiquidate.  # noqa: E501
        :type: str
        """

        self._fill_price = fill_price

    @property
    def left(self):
        """Gets the left of this FuturesLiquidate.  # noqa: E501

        Liquidation order maker size  # noqa: E501

        :return: The left of this FuturesLiquidate.  # noqa: E501
        :rtype: int
        """
        return self._left

    @left.setter
    def left(self, left):
        """Sets the left of this FuturesLiquidate.

        Liquidation order maker size  # noqa: E501

        :param left: The left of this FuturesLiquidate.  # noqa: E501
        :type: int
        """

        self._left = left

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FuturesLiquidate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FuturesLiquidate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class OrderBook(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'current': 'int',
        'update': 'int',
        'asks': 'list[list[str]]',
        'bids': 'list[list[str]]',
    }

    attribute_map = {'id': 'id', 'current': 'current', 'update': 'update', 'asks': 'asks', 'bids': 'bids'}

    def __init__(
        self, id=None, current=None, update=None, asks=None, bids=None, local_vars_configuration=None
    ):  # noqa: E501
        # type: (int, int, int, list[list[str]], list[list[str]], Configuration) -> None
        """OrderBook - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._current = None
        self._update = None
        self._asks = None
        self._bids = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if current is not None:
            self.current = current
        if update is not None:
            self.update = update
        self.asks = asks
        self.bids = bids

    @property
    def id(self):
        """Gets the id of this OrderBook.  # noqa: E501

        Order book ID, which is updated whenever the order book is changed. Valid only when `with_id` is set to `true`  # noqa: E501

        :return: The id of this OrderBook.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrderBook.

        Order book ID, which is updated whenever the order book is changed. Valid only when `with_id` is set to `true`  # noqa: E501

        :param id: The id of this OrderBook.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def current(self):
        """Gets the current of this OrderBook.  # noqa: E501

        The timestamp of the response data being generated (in milliseconds)  # noqa: E501

        :return: The current of this OrderBook.  # noqa: E501
        :rtype: int
        """
        return self._current

    @current.setter
    def current(self, current):
        """Sets the current of this OrderBook.

        The timestamp of the response data being generated (in milliseconds)  # noqa: E501

        :param current: The current of this OrderBook.  # noqa: E501
        :type: int
        """

        self._current = current

    @property
    def update(self):
        """Gets the update of this OrderBook.  # noqa: E501

        The timestamp of when the orderbook last changed (in milliseconds)  # noqa: E501

        :return: The update of this OrderBook.  # noqa: E501
        :rtype: int
        """
        return self._update

    @update.setter
    def update(self, update):
        """Sets the update of this OrderBook.

        The timestamp of when the orderbook last changed (in milliseconds)  # noqa: E501

        :param update: The update of this OrderBook.  # noqa: E501
        :type: int
        """

        self._update = update

    @property
    def asks(self):
        """Gets the asks of this OrderBook.  # noqa: E501

        Asks order depth  # noqa: E501

        :return: The asks of this OrderBook.  # noqa: E501
        :rtype: list[list[str]]
        """
        return self._asks

    @asks.setter
    def asks(self, asks):
        """Sets the asks of this OrderBook.

        Asks order depth  # noqa: E501

        :param asks: The asks of this OrderBook.  # noqa: E501
        :type: list[list[str]]
        """
        if self.local_vars_configuration.client_side_validation and asks is None:  # noqa: E501
            raise ValueError("Invalid value for `asks`, must not be `None`")  # noqa: E501

        self._asks = asks

    @property
    def bids(self):
        """Gets the bids of this OrderBook.  # noqa: E501

        Bids order depth  # noqa: E501

        :return: The bids of this OrderBook.  # noqa: E501
        :rtype: list[list[str]]
        """
        return self._bids

    @bids.setter
    def bids(self, bids):
        """Sets the bids of this OrderBook.

        Bids order depth  # noqa: E501

        :param bids: The bids of this OrderBook.  # noqa: E501
        :type: list[list[str]]
        """
        if self.local_vars_configuration.client_side_validation and bids is None:  # noqa: E501
            raise ValueError("Invalid value for `bids`, must not be `None`")  # noqa: E501

        self._bids = bids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderBook):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrderBook):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class MarginAccountBook(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'time': 'str',
        'time_ms': 'int',
        'currency': 'str',
        'currency_pair': 'str',
        'change': 'str',
        'balance': 'str',
    }

    attribute_map = {
        'id': 'id',
        'time': 'time',
        'time_ms': 'time_ms',
        'currency': 'currency',
        'currency_pair': 'currency_pair',
        'change': 'change',
        'balance': 'balance',
    }

    def __init__(
        self,
        id=None,
        time=None,
        time_ms=None,
        currency=None,
        currency_pair=None,
        change=None,
        balance=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (str, str, int, str, str, str, str, Configuration) -> None
        """MarginAccountBook - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._time = None
        self._time_ms = None
        self._currency = None
        self._currency_pair = None
        self._change = None
        self._balance = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if time is not None:
            self.time = time
        if time_ms is not None:
            self.time_ms = time_ms
        if currency is not None:
            self.currency = currency
        if currency_pair is not None:
            self.currency_pair = currency_pair
        if change is not None:
            self.change = change
        if balance is not None:
            self.balance = balance

    @property
    def id(self):
        """Gets the id of this MarginAccountBook.  # noqa: E501

        Balance change record ID  # noqa: E501

        :return: The id of this MarginAccountBook.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MarginAccountBook.

        Balance change record ID  # noqa: E501

        :param id: The id of this MarginAccountBook.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def time(self):
        """Gets the time of this MarginAccountBook.  # noqa: E501

        Balance changed timestamp  # noqa: E501

        :return: The time of this MarginAccountBook.  # noqa: E501
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this MarginAccountBook.

        Balance changed timestamp  # noqa: E501

        :param time: The time of this MarginAccountBook.  # noqa: E501
        :type: str
        """

        self._time = time

    @property
    def time_ms(self):
        """Gets the time_ms of this MarginAccountBook.  # noqa: E501

        The timestamp of the change (in milliseconds)  # noqa: E501

        :return: The time_ms of this MarginAccountBook.  # noqa: E501
        :rtype: int
        """
        return self._time_ms

    @time_ms.setter
    def time_ms(self, time_ms):
        """Sets the time_ms of this MarginAccountBook.

        The timestamp of the change (in milliseconds)  # noqa: E501

        :param time_ms: The time_ms of this MarginAccountBook.  # noqa: E501
        :type: int
        """

        self._time_ms = time_ms

    @property
    def currency(self):
        """Gets the currency of this MarginAccountBook.  # noqa: E501

        Currency changed  # noqa: E501

        :return: The currency of this MarginAccountBook.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this MarginAccountBook.

        Currency changed  # noqa: E501

        :param currency: The currency of this MarginAccountBook.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def currency_pair(self):
        """Gets the currency_pair of this MarginAccountBook.  # noqa: E501

        Account currency pair  # noqa: E501

        :return: The currency_pair of this MarginAccountBook.  # noqa: E501
        :rtype: str
        """
        return self._currency_pair

    @currency_pair.setter
    def currency_pair(self, currency_pair):
        """Sets the currency_pair of this MarginAccountBook.

        Account currency pair  # noqa: E501

        :param currency_pair: The currency_pair of this MarginAccountBook.  # noqa: E501
        :type: str
        """

        self._currency_pair = currency_pair

    @property
    def change(self):
        """Gets the change of this MarginAccountBook.  # noqa: E501

        Amount changed. Positive value means transferring in, while negative out  # noqa: E501

        :return: The change of this MarginAccountBook.  # noqa: E501
        :rtype: str
        """
        return self._change

    @change.setter
    def change(self, change):
        """Sets the change of this MarginAccountBook.

        Amount changed. Positive value means transferring in, while negative out  # noqa: E501

        :param change: The change of this MarginAccountBook.  # noqa: E501
        :type: str
        """

        self._change = change

    @property
    def balance(self):
        """Gets the balance of this MarginAccountBook.  # noqa: E501

        Balance after change  # noqa: E501

        :return: The balance of this MarginAccountBook.  # noqa: E501
        :rtype: str
        """
        return self._balance

    @balance.setter
    def balance(self, balance):
        """Sets the balance of this MarginAccountBook.

        Balance after change  # noqa: E501

        :param balance: The balance of this MarginAccountBook.  # noqa: E501
        :type: str
        """

        self._balance = balance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MarginAccountBook):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MarginAccountBook):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class MarginCurrencyPair(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'base': 'str',
        'quote': 'str',
        'leverage': 'int',
        'min_base_amount': 'str',
        'min_quote_amount': 'str',
        'max_quote_amount': 'str',
    }

    attribute_map = {
        'id': 'id',
        'base': 'base',
        'quote': 'quote',
        'leverage': 'leverage',
        'min_base_amount': 'min_base_amount',
        'min_quote_amount': 'min_quote_amount',
        'max_quote_amount': 'max_quote_amount',
    }

    def __init__(
        self,
        id=None,
        base=None,
        quote=None,
        leverage=None,
        min_base_amount=None,
        min_quote_amount=None,
        max_quote_amount=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (str, str, str, int, str, str, str, Configuration) -> None
        """MarginCurrencyPair - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._base = None
        self._quote = None
        self._leverage = None
        self._min_base_amount = None
        self._min_quote_amount = None
        self._max_quote_amount = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if base is not None:
            self.base = base
        if quote is not None:
            self.quote = quote
        if leverage is not None:
            self.leverage = leverage
        if min_base_amount is not None:
            self.min_base_amount = min_base_amount
        if min_quote_amount is not None:
            self.min_quote_amount = min_quote_amount
        if max_quote_amount is not None:
            self.max_quote_amount = max_quote_amount

    @property
    def id(self):
        """Gets the id of this MarginCurrencyPair.  # noqa: E501

        Currency pair  # noqa: E501

        :return: The id of this MarginCurrencyPair.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MarginCurrencyPair.

        Currency pair  # noqa: E501

        :param id: The id of this MarginCurrencyPair.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def base(self):
        """Gets the base of this MarginCurrencyPair.  # noqa: E501

        Base currency  # noqa: E501

        :return: The base of this MarginCurrencyPair.  # noqa: E501
        :rtype: str
        """
        return self._base

    @base.setter
    def base(self, base):
        """Sets the base of this MarginCurrencyPair.

        Base currency  # noqa: E501

        :param base: The base of this MarginCurrencyPair.  # noqa: E501
        :type: str
        """

        self._base = base

    @property
    def quote(self):
        """Gets the quote of this MarginCurrencyPair.  # noqa: E501

        Quote currency  # noqa: E501

        :return: The quote of this MarginCurrencyPair.  # noqa: E501
        :rtype: str
        """
        return self._quote

    @quote.setter
    def quote(self, quote):
        """Sets the quote of this MarginCurrencyPair.

        Quote currency  # noqa: E501

        :param quote: The quote of this MarginCurrencyPair.  # noqa: E501
        :type: str
        """

        self._quote = quote

    @property
    def leverage(self):
        """Gets the leverage of this MarginCurrencyPair.  # noqa: E501

        Leverage  # noqa: E501

        :return: The leverage of this MarginCurrencyPair.  # noqa: E501
        :rtype: int
        """
        return self._leverage

    @leverage.setter
    def leverage(self, leverage):
        """Sets the leverage of this MarginCurrencyPair.

        Leverage  # noqa: E501

        :param leverage: The leverage of this MarginCurrencyPair.  # noqa: E501
        :type: int
        """

        self._leverage = leverage

    @property
    def min_base_amount(self):
        """Gets the min_base_amount of this MarginCurrencyPair.  # noqa: E501

        Minimum base currency to loan, `null` means no limit  # noqa: E501

        :return: The min_base_amount of this MarginCurrencyPair.  # noqa: E501
        :rtype: str
        """
        return self._min_base_amount

    @min_base_amount.setter
    def min_base_amount(self, min_base_amount):
        """Sets the min_base_amount of this MarginCurrencyPair.

        Minimum base currency to loan, `null` means no limit  # noqa: E501

        :param min_base_amount: The min_base_amount of this MarginCurrencyPair.  # noqa: E501
        :type: str
        """

        self._min_base_amount = min_base_amount

    @property
    def min_quote_amount(self):
        """Gets the min_quote_amount of this MarginCurrencyPair.  # noqa: E501

        Minimum quote currency to loan, `null` means no limit  # noqa: E501

        :return: The min_quote_amount of this MarginCurrencyPair.  # noqa: E501
        :rtype: str
        """
        return self._min_quote_amount

    @min_quote_amount.setter
    def min_quote_amount(self, min_quote_amount):
        """Sets the min_quote_amount of this MarginCurrencyPair.

        Minimum quote currency to loan, `null` means no limit  # noqa: E501

        :param min_quote_amount: The min_quote_amount of this MarginCurrencyPair.  # noqa: E501
        :type: str
        """

        self._min_quote_amount = min_quote_amount

    @property
    def max_quote_amount(self):
        """Gets the max_quote_amount of this MarginCurrencyPair.  # noqa: E501

        Maximum borrowable amount for quote currency. Base currency limit is calculated by quote maximum and market price. `null` means no limit  # noqa: E501

        :return: The max_quote_amount of this MarginCurrencyPair.  # noqa: E501
        :rtype: str
        """
        return self._max_quote_amount

    @max_quote_amount.setter
    def max_quote_amount(self, max_quote_amount):
        """Sets the max_quote_amount of this MarginCurrencyPair.

        Maximum borrowable amount for quote currency. Base currency limit is calculated by quote maximum and market price. `null` means no limit  # noqa: E501

        :param max_quote_amount: The max_quote_amount of this MarginCurrencyPair.  # noqa: E501
        :type: str
        """

        self._max_quote_amount = max_quote_amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MarginCurrencyPair):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MarginCurrencyPair):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class LedgerRecord(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'txid': 'str',
        'timestamp': 'str',
        'amount': 'str',
        'currency': 'str',
        'address': 'str',
        'memo': 'str',
        'status': 'str',
        'chain': 'str',
        'fee': 'str',
    }

    attribute_map = {
        'id': 'id',
        'txid': 'txid',
        'timestamp': 'timestamp',
        'amount': 'amount',
        'currency': 'currency',
        'address': 'address',
        'memo': 'memo',
        'status': 'status',
        'chain': 'chain',
        'fee': 'fee',
    }

    def __init__(
        self,
        id=None,
        txid=None,
        timestamp=None,
        amount=None,
        currency=None,
        address=None,
        memo=None,
        status=None,
        chain=None,
        fee=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (str, str, str, str, str, str, str, str, str, str, Configuration) -> None
        """LedgerRecord - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._txid = None
        self._timestamp = None
        self._amount = None
        self._currency = None
        self._address = None
        self._memo = None
        self._status = None
        self._chain = None
        self._fee = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if txid is not None:
            self.txid = txid
        if timestamp is not None:
            self.timestamp = timestamp
        self.amount = amount
        self.currency = currency
        if address is not None:
            self.address = address
        if memo is not None:
            self.memo = memo
        if status is not None:
            self.status = status
        if chain is not None:
            self.chain = chain
        if fee is not None:
            self.fee = fee

    @property
    def id(self):
        """Gets the id of this LedgerRecord.  # noqa: E501

        Record ID  # noqa: E501

        :return: The id of this LedgerRecord.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LedgerRecord.

        Record ID  # noqa: E501

        :param id: The id of this LedgerRecord.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def txid(self):
        """Gets the txid of this LedgerRecord.  # noqa: E501

        Hash record of the withdrawal  # noqa: E501

        :return: The txid of this LedgerRecord.  # noqa: E501
        :rtype: str
        """
        return self._txid

    @txid.setter
    def txid(self, txid):
        """Sets the txid of this LedgerRecord.

        Hash record of the withdrawal  # noqa: E501

        :param txid: The txid of this LedgerRecord.  # noqa: E501
        :type: str
        """

        self._txid = txid

    @property
    def timestamp(self):
        """Gets the timestamp of this LedgerRecord.  # noqa: E501

        Operation time  # noqa: E501

        :return: The timestamp of this LedgerRecord.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this LedgerRecord.

        Operation time  # noqa: E501

        :param timestamp: The timestamp of this LedgerRecord.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    @property
    def amount(self):
        """Gets the amount of this LedgerRecord.  # noqa: E501

        Currency amount  # noqa: E501

        :return: The amount of this LedgerRecord.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this LedgerRecord.

        Currency amount  # noqa: E501

        :param amount: The amount of this LedgerRecord.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this LedgerRecord.  # noqa: E501

        Currency name  # noqa: E501

        :return: The currency of this LedgerRecord.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this LedgerRecord.

        Currency name  # noqa: E501

        :param currency: The currency of this LedgerRecord.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and currency is None:  # noqa: E501
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501

        self._currency = currency

    @property
    def address(self):
        """Gets the address of this LedgerRecord.  # noqa: E501

        Withdrawal address. Required for withdrawals  # noqa: E501

        :return: The address of this LedgerRecord.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this LedgerRecord.

        Withdrawal address. Required for withdrawals  # noqa: E501

        :param address: The address of this LedgerRecord.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def memo(self):
        """Gets the memo of this LedgerRecord.  # noqa: E501

        Additional remarks with regards to the withdrawal  # noqa: E501

        :return: The memo of this LedgerRecord.  # noqa: E501
        :rtype: str
        """
        return self._memo

    @memo.setter
    def memo(self, memo):
        """Sets the memo of this LedgerRecord.

        Additional remarks with regards to the withdrawal  # noqa: E501

        :param memo: The memo of this LedgerRecord.  # noqa: E501
        :type: str
        """

        self._memo = memo

    @property
    def status(self):
        """Gets the status of this LedgerRecord.  # noqa: E501

        Record status.  - DONE: done - CANCEL: cancelled - REQUEST: requesting - MANUAL: pending manual approval - BCODE: GateCode operation - EXTPEND: pending confirm after sending - FAIL: pending confirm when fail - INVALID: invalid order - VERIFY: verifying - PROCES: processing - PEND: pending  # noqa: E501

        :return: The status of this LedgerRecord.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this LedgerRecord.

        Record status.  - DONE: done - CANCEL: cancelled - REQUEST: requesting - MANUAL: pending manual approval - BCODE: GateCode operation - EXTPEND: pending confirm after sending - FAIL: pending confirm when fail - INVALID: invalid order - VERIFY: verifying - PROCES: processing - PEND: pending  # noqa: E501

        :param status: The status of this LedgerRecord.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "DONE",
            "CANCEL",
            "REQUEST",
            "MANUAL",
            "BCODE",
            "EXTPEND",
            "FAIL",
            "INVALID",
            "VERIFY",
            "PROCES",
            "PEND",
        ]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(status, allowed_values)  # noqa: E501
            )

        self._status = status

    @property
    def chain(self):
        """Gets the chain of this LedgerRecord.  # noqa: E501

        Name of the chain used in withdrawals  # noqa: E501

        :return: The chain of this LedgerRecord.  # noqa: E501
        :rtype: str
        """
        return self._chain

    @chain.setter
    def chain(self, chain):
        """Sets the chain of this LedgerRecord.

        Name of the chain used in withdrawals  # noqa: E501

        :param chain: The chain of this LedgerRecord.  # noqa: E501
        :type: str
        """

        self._chain = chain

    @property
    def fee(self):
        """Gets the fee of this LedgerRecord.  # noqa: E501

        Fee  # noqa: E501

        :return: The fee of this LedgerRecord.  # noqa: E501
        :rtype: str
        """
        return self._fee

    @fee.setter
    def fee(self, fee):
        """Sets the fee of this LedgerRecord.

        Fee  # noqa: E501

        :param fee: The fee of this LedgerRecord.  # noqa: E501
        :type: str
        """

        self._fee = fee

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LedgerRecord):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LedgerRecord):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class SpotPriceTriggeredOrder(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'trigger': 'SpotPriceTrigger',
        'put': 'SpotPricePutOrder',
        'id': 'int',
        'user': 'int',
        'market': 'str',
        'ctime': 'int',
        'ftime': 'int',
        'fired_order_id': 'int',
        'status': 'str',
        'reason': 'str',
    }

    attribute_map = {
        'trigger': 'trigger',
        'put': 'put',
        'id': 'id',
        'user': 'user',
        'market': 'market',
        'ctime': 'ctime',
        'ftime': 'ftime',
        'fired_order_id': 'fired_order_id',
        'status': 'status',
        'reason': 'reason',
    }

    def __init__(
        self,
        trigger=None,
        put=None,
        id=None,
        user=None,
        market=None,
        ctime=None,
        ftime=None,
        fired_order_id=None,
        status=None,
        reason=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (SpotPriceTrigger, SpotPricePutOrder, int, int, str, int, int, int, str, str, Configuration) -> None
        """SpotPriceTriggeredOrder - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._trigger = None
        self._put = None
        self._id = None
        self._user = None
        self._market = None
        self._ctime = None
        self._ftime = None
        self._fired_order_id = None
        self._status = None
        self._reason = None
        self.discriminator = None

        self.trigger = trigger
        self.put = put
        if id is not None:
            self.id = id
        if user is not None:
            self.user = user
        self.market = market
        if ctime is not None:
            self.ctime = ctime
        if ftime is not None:
            self.ftime = ftime
        if fired_order_id is not None:
            self.fired_order_id = fired_order_id
        if status is not None:
            self.status = status
        if reason is not None:
            self.reason = reason

    @property
    def trigger(self):
        """Gets the trigger of this SpotPriceTriggeredOrder.  # noqa: E501


        :return: The trigger of this SpotPriceTriggeredOrder.  # noqa: E501
        :rtype: SpotPriceTrigger
        """
        return self._trigger

    @trigger.setter
    def trigger(self, trigger):
        """Sets the trigger of this SpotPriceTriggeredOrder.


        :param trigger: The trigger of this SpotPriceTriggeredOrder.  # noqa: E501
        :type: SpotPriceTrigger
        """
        if self.local_vars_configuration.client_side_validation and trigger is None:  # noqa: E501
            raise ValueError("Invalid value for `trigger`, must not be `None`")  # noqa: E501

        self._trigger = trigger

    @property
    def put(self):
        """Gets the put of this SpotPriceTriggeredOrder.  # noqa: E501


        :return: The put of this SpotPriceTriggeredOrder.  # noqa: E501
        :rtype: SpotPricePutOrder
        """
        return self._put

    @put.setter
    def put(self, put):
        """Sets the put of this SpotPriceTriggeredOrder.


        :param put: The put of this SpotPriceTriggeredOrder.  # noqa: E501
        :type: SpotPricePutOrder
        """
        if self.local_vars_configuration.client_side_validation and put is None:  # noqa: E501
            raise ValueError("Invalid value for `put`, must not be `None`")  # noqa: E501

        self._put = put

    @property
    def id(self):
        """Gets the id of this SpotPriceTriggeredOrder.  # noqa: E501

        Auto order ID  # noqa: E501

        :return: The id of this SpotPriceTriggeredOrder.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SpotPriceTriggeredOrder.

        Auto order ID  # noqa: E501

        :param id: The id of this SpotPriceTriggeredOrder.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def user(self):
        """Gets the user of this SpotPriceTriggeredOrder.  # noqa: E501

        User ID  # noqa: E501

        :return: The user of this SpotPriceTriggeredOrder.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this SpotPriceTriggeredOrder.

        User ID  # noqa: E501

        :param user: The user of this SpotPriceTriggeredOrder.  # noqa: E501
        :type: int
        """

        self._user = user

    @property
    def market(self):
        """Gets the market of this SpotPriceTriggeredOrder.  # noqa: E501

        Currency pair  # noqa: E501

        :return: The market of this SpotPriceTriggeredOrder.  # noqa: E501
        :rtype: str
        """
        return self._market

    @market.setter
    def market(self, market):
        """Sets the market of this SpotPriceTriggeredOrder.

        Currency pair  # noqa: E501

        :param market: The market of this SpotPriceTriggeredOrder.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and market is None:  # noqa: E501
            raise ValueError("Invalid value for `market`, must not be `None`")  # noqa: E501

        self._market = market

    @property
    def ctime(self):
        """Gets the ctime of this SpotPriceTriggeredOrder.  # noqa: E501

        Creation time  # noqa: E501

        :return: The ctime of this SpotPriceTriggeredOrder.  # noqa: E501
        :rtype: int
        """
        return self._ctime

    @ctime.setter
    def ctime(self, ctime):
        """Sets the ctime of this SpotPriceTriggeredOrder.

        Creation time  # noqa: E501

        :param ctime: The ctime of this SpotPriceTriggeredOrder.  # noqa: E501
        :type: int
        """

        self._ctime = ctime

    @property
    def ftime(self):
        """Gets the ftime of this SpotPriceTriggeredOrder.  # noqa: E501

        Finished time  # noqa: E501

        :return: The ftime of this SpotPriceTriggeredOrder.  # noqa: E501
        :rtype: int
        """
        return self._ftime

    @ftime.setter
    def ftime(self, ftime):
        """Sets the ftime of this SpotPriceTriggeredOrder.

        Finished time  # noqa: E501

        :param ftime: The ftime of this SpotPriceTriggeredOrder.  # noqa: E501
        :type: int
        """

        self._ftime = ftime

    @property
    def fired_order_id(self):
        """Gets the fired_order_id of this SpotPriceTriggeredOrder.  # noqa: E501

        ID of the newly created order on condition triggered  # noqa: E501

        :return: The fired_order_id of this SpotPriceTriggeredOrder.  # noqa: E501
        :rtype: int
        """
        return self._fired_order_id

    @fired_order_id.setter
    def fired_order_id(self, fired_order_id):
        """Sets the fired_order_id of this SpotPriceTriggeredOrder.

        ID of the newly created order on condition triggered  # noqa: E501

        :param fired_order_id: The fired_order_id of this SpotPriceTriggeredOrder.  # noqa: E501
        :type: int
        """

        self._fired_order_id = fired_order_id

    @property
    def status(self):
        """Gets the status of this SpotPriceTriggeredOrder.  # noqa: E501

        Status  - open: open - cancelled: being manually cancelled - finish: successfully executed - failed: failed to execute - expired - expired   # noqa: E501

        :return: The status of this SpotPriceTriggeredOrder.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SpotPriceTriggeredOrder.

        Status  - open: open - cancelled: being manually cancelled - finish: successfully executed - failed: failed to execute - expired - expired   # noqa: E501

        :param status: The status of this SpotPriceTriggeredOrder.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def reason(self):
        """Gets the reason of this SpotPriceTriggeredOrder.  # noqa: E501

        Additional remarks on how the order was finished  # noqa: E501

        :return: The reason of this SpotPriceTriggeredOrder.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this SpotPriceTriggeredOrder.

        Additional remarks on how the order was finished  # noqa: E501

        :param reason: The reason of this SpotPriceTriggeredOrder.  # noqa: E501
        :type: str
        """

        self._reason = reason

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpotPriceTriggeredOrder):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SpotPriceTriggeredOrder):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class Order(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'text': 'str',
        'create_time': 'str',
        'update_time': 'str',
        'create_time_ms': 'int',
        'update_time_ms': 'int',
        'status': 'str',
        'currency_pair': 'str',
        'type': 'str',
        'account': 'str',
        'side': 'str',
        'amount': 'str',
        'price': 'str',
        'time_in_force': 'str',
        'iceberg': 'str',
        'auto_borrow': 'bool',
        'auto_repay': 'bool',
        'left': 'str',
        'fill_price': 'str',
        'filled_total': 'str',
        'fee': 'str',
        'fee_currency': 'str',
        'point_fee': 'str',
        'gt_fee': 'str',
        'gt_discount': 'bool',
        'rebated_fee': 'str',
        'rebated_fee_currency': 'str',
    }

    attribute_map = {
        'id': 'id',
        'text': 'text',
        'create_time': 'create_time',
        'update_time': 'update_time',
        'create_time_ms': 'create_time_ms',
        'update_time_ms': 'update_time_ms',
        'status': 'status',
        'currency_pair': 'currency_pair',
        'type': 'type',
        'account': 'account',
        'side': 'side',
        'amount': 'amount',
        'price': 'price',
        'time_in_force': 'time_in_force',
        'iceberg': 'iceberg',
        'auto_borrow': 'auto_borrow',
        'auto_repay': 'auto_repay',
        'left': 'left',
        'fill_price': 'fill_price',
        'filled_total': 'filled_total',
        'fee': 'fee',
        'fee_currency': 'fee_currency',
        'point_fee': 'point_fee',
        'gt_fee': 'gt_fee',
        'gt_discount': 'gt_discount',
        'rebated_fee': 'rebated_fee',
        'rebated_fee_currency': 'rebated_fee_currency',
    }

    def __init__(
        self,
        id=None,
        text=None,
        create_time=None,
        update_time=None,
        create_time_ms=None,
        update_time_ms=None,
        status=None,
        currency_pair=None,
        type='limit',
        account='spot',
        side=None,
        amount=None,
        price=None,
        time_in_force='gtc',
        iceberg=None,
        auto_borrow=None,
        auto_repay=None,
        left=None,
        fill_price=None,
        filled_total=None,
        fee=None,
        fee_currency=None,
        point_fee=None,
        gt_fee=None,
        gt_discount=None,
        rebated_fee=None,
        rebated_fee_currency=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (str, str, str, str, int, int, str, str, str, str, str, str, str, str, str, bool, bool, str, str, str, str, str, str, str, bool, str, str, Configuration) -> None
        """Order - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._text = None
        self._create_time = None
        self._update_time = None
        self._create_time_ms = None
        self._update_time_ms = None
        self._status = None
        self._currency_pair = None
        self._type = None
        self._account = None
        self._side = None
        self._amount = None
        self._price = None
        self._time_in_force = None
        self._iceberg = None
        self._auto_borrow = None
        self._auto_repay = None
        self._left = None
        self._fill_price = None
        self._filled_total = None
        self._fee = None
        self._fee_currency = None
        self._point_fee = None
        self._gt_fee = None
        self._gt_discount = None
        self._rebated_fee = None
        self._rebated_fee_currency = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if text is not None:
            self.text = text
        if create_time is not None:
            self.create_time = create_time
        if update_time is not None:
            self.update_time = update_time
        if create_time_ms is not None:
            self.create_time_ms = create_time_ms
        if update_time_ms is not None:
            self.update_time_ms = update_time_ms
        if status is not None:
            self.status = status
        self.currency_pair = currency_pair
        if type is not None:
            self.type = type
        if account is not None:
            self.account = account
        self.side = side
        self.amount = amount
        self.price = price
        if time_in_force is not None:
            self.time_in_force = time_in_force
        if iceberg is not None:
            self.iceberg = iceberg
        if auto_borrow is not None:
            self.auto_borrow = auto_borrow
        if auto_repay is not None:
            self.auto_repay = auto_repay
        if left is not None:
            self.left = left
        if fill_price is not None:
            self.fill_price = fill_price
        if filled_total is not None:
            self.filled_total = filled_total
        if fee is not None:
            self.fee = fee
        if fee_currency is not None:
            self.fee_currency = fee_currency
        if point_fee is not None:
            self.point_fee = point_fee
        if gt_fee is not None:
            self.gt_fee = gt_fee
        if gt_discount is not None:
            self.gt_discount = gt_discount
        if rebated_fee is not None:
            self.rebated_fee = rebated_fee
        if rebated_fee_currency is not None:
            self.rebated_fee_currency = rebated_fee_currency

    @property
    def id(self):
        """Gets the id of this Order.  # noqa: E501

        Order ID  # noqa: E501

        :return: The id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Order.

        Order ID  # noqa: E501

        :param id: The id of this Order.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def text(self):
        """Gets the text of this Order.  # noqa: E501

        User defined information. If not empty, must follow the rules below:  1. prefixed with `t-` 2. no longer than 28 bytes without `t-` prefix 3. can only include 0-9, A-Z, a-z, underscore(_), hyphen(-) or dot(.)   # noqa: E501

        :return: The text of this Order.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this Order.

        User defined information. If not empty, must follow the rules below:  1. prefixed with `t-` 2. no longer than 28 bytes without `t-` prefix 3. can only include 0-9, A-Z, a-z, underscore(_), hyphen(-) or dot(.)   # noqa: E501

        :param text: The text of this Order.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def create_time(self):
        """Gets the create_time of this Order.  # noqa: E501

        Creation time of order  # noqa: E501

        :return: The create_time of this Order.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this Order.

        Creation time of order  # noqa: E501

        :param create_time: The create_time of this Order.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def update_time(self):
        """Gets the update_time of this Order.  # noqa: E501

        Last modification time of order  # noqa: E501

        :return: The update_time of this Order.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this Order.

        Last modification time of order  # noqa: E501

        :param update_time: The update_time of this Order.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    @property
    def create_time_ms(self):
        """Gets the create_time_ms of this Order.  # noqa: E501

        Creation time of order (in milliseconds)  # noqa: E501

        :return: The create_time_ms of this Order.  # noqa: E501
        :rtype: int
        """
        return self._create_time_ms

    @create_time_ms.setter
    def create_time_ms(self, create_time_ms):
        """Sets the create_time_ms of this Order.

        Creation time of order (in milliseconds)  # noqa: E501

        :param create_time_ms: The create_time_ms of this Order.  # noqa: E501
        :type: int
        """

        self._create_time_ms = create_time_ms

    @property
    def update_time_ms(self):
        """Gets the update_time_ms of this Order.  # noqa: E501

        Last modification time of order (in milliseconds)  # noqa: E501

        :return: The update_time_ms of this Order.  # noqa: E501
        :rtype: int
        """
        return self._update_time_ms

    @update_time_ms.setter
    def update_time_ms(self, update_time_ms):
        """Sets the update_time_ms of this Order.

        Last modification time of order (in milliseconds)  # noqa: E501

        :param update_time_ms: The update_time_ms of this Order.  # noqa: E501
        :type: int
        """

        self._update_time_ms = update_time_ms

    @property
    def status(self):
        """Gets the status of this Order.  # noqa: E501

        Order status  - `open`: to be filled - `closed`: filled - `cancelled`: cancelled  # noqa: E501

        :return: The status of this Order.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Order.

        Order status  - `open`: to be filled - `closed`: filled - `cancelled`: cancelled  # noqa: E501

        :param status: The status of this Order.  # noqa: E501
        :type: str
        """
        allowed_values = ["open", "closed", "cancelled"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(status, allowed_values)  # noqa: E501
            )

        self._status = status

    @property
    def currency_pair(self):
        """Gets the currency_pair of this Order.  # noqa: E501

        Currency pair  # noqa: E501

        :return: The currency_pair of this Order.  # noqa: E501
        :rtype: str
        """
        return self._currency_pair

    @currency_pair.setter
    def currency_pair(self, currency_pair):
        """Sets the currency_pair of this Order.

        Currency pair  # noqa: E501

        :param currency_pair: The currency_pair of this Order.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and currency_pair is None:  # noqa: E501
            raise ValueError("Invalid value for `currency_pair`, must not be `None`")  # noqa: E501

        self._currency_pair = currency_pair

    @property
    def type(self):
        """Gets the type of this Order.  # noqa: E501

        Order type. limit - limit order  # noqa: E501

        :return: The type of this Order.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Order.

        Order type. limit - limit order  # noqa: E501

        :param type: The type of this Order.  # noqa: E501
        :type: str
        """
        allowed_values = ["limit"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}".format(type, allowed_values)  # noqa: E501
            )

        self._type = type

    @property
    def account(self):
        """Gets the account of this Order.  # noqa: E501

        Account type. spot - use spot account; margin - use margin account; cross_margin - use cross margin account  # noqa: E501

        :return: The account of this Order.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this Order.

        Account type. spot - use spot account; margin - use margin account; cross_margin - use cross margin account  # noqa: E501

        :param account: The account of this Order.  # noqa: E501
        :type: str
        """
        allowed_values = ["spot", "margin", "cross_margin"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and account not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `account` ({0}), must be one of {1}".format(account, allowed_values)  # noqa: E501
            )

        self._account = account

    @property
    def side(self):
        """Gets the side of this Order.  # noqa: E501

        Order side  # noqa: E501

        :return: The side of this Order.  # noqa: E501
        :rtype: str
        """
        return self._side

    @side.setter
    def side(self, side):
        """Sets the side of this Order.

        Order side  # noqa: E501

        :param side: The side of this Order.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and side is None:  # noqa: E501
            raise ValueError("Invalid value for `side`, must not be `None`")  # noqa: E501
        allowed_values = ["buy", "sell"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and side not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `side` ({0}), must be one of {1}".format(side, allowed_values)  # noqa: E501
            )

        self._side = side

    @property
    def amount(self):
        """Gets the amount of this Order.  # noqa: E501

        Trade amount  # noqa: E501

        :return: The amount of this Order.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Order.

        Trade amount  # noqa: E501

        :param amount: The amount of this Order.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def price(self):
        """Gets the price of this Order.  # noqa: E501

        Order price  # noqa: E501

        :return: The price of this Order.  # noqa: E501
        :rtype: str
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this Order.

        Order price  # noqa: E501

        :param price: The price of this Order.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and price is None:  # noqa: E501
            raise ValueError("Invalid value for `price`, must not be `None`")  # noqa: E501

        self._price = price

    @property
    def time_in_force(self):
        """Gets the time_in_force of this Order.  # noqa: E501

        Time in force  - gtc: GoodTillCancelled - ioc: ImmediateOrCancelled, taker only - poc: PendingOrCancelled, makes a post-only order that always enjoys a maker fee - fok: FillOrKill, fill either completely or none  # noqa: E501

        :return: The time_in_force of this Order.  # noqa: E501
        :rtype: str
        """
        return self._time_in_force

    @time_in_force.setter
    def time_in_force(self, time_in_force):
        """Sets the time_in_force of this Order.

        Time in force  - gtc: GoodTillCancelled - ioc: ImmediateOrCancelled, taker only - poc: PendingOrCancelled, makes a post-only order that always enjoys a maker fee - fok: FillOrKill, fill either completely or none  # noqa: E501

        :param time_in_force: The time_in_force of this Order.  # noqa: E501
        :type: str
        """
        allowed_values = ["gtc", "ioc", "poc", "fok"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and time_in_force not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `time_in_force` ({0}), must be one of {1}".format(  # noqa: E501
                    time_in_force, allowed_values
                )
            )

        self._time_in_force = time_in_force

    @property
    def iceberg(self):
        """Gets the iceberg of this Order.  # noqa: E501

        Amount to display for the iceberg order. Null or 0 for normal orders. Set to -1 to hide the order completely  # noqa: E501

        :return: The iceberg of this Order.  # noqa: E501
        :rtype: str
        """
        return self._iceberg

    @iceberg.setter
    def iceberg(self, iceberg):
        """Sets the iceberg of this Order.

        Amount to display for the iceberg order. Null or 0 for normal orders. Set to -1 to hide the order completely  # noqa: E501

        :param iceberg: The iceberg of this Order.  # noqa: E501
        :type: str
        """

        self._iceberg = iceberg

    @property
    def auto_borrow(self):
        """Gets the auto_borrow of this Order.  # noqa: E501

        Used in margin or cross margin trading to allow automatic loan of insufficient amount if balance is not enough.  # noqa: E501

        :return: The auto_borrow of this Order.  # noqa: E501
        :rtype: bool
        """
        return self._auto_borrow

    @auto_borrow.setter
    def auto_borrow(self, auto_borrow):
        """Sets the auto_borrow of this Order.

        Used in margin or cross margin trading to allow automatic loan of insufficient amount if balance is not enough.  # noqa: E501

        :param auto_borrow: The auto_borrow of this Order.  # noqa: E501
        :type: bool
        """

        self._auto_borrow = auto_borrow

    @property
    def auto_repay(self):
        """Gets the auto_repay of this Order.  # noqa: E501

        Enable or disable automatic repayment for automatic borrow loan generated by cross margin order. Default is disabled. Note that:  1. This field is only effective for cross margin orders. Margin account does not support setting auto repayment for orders. 2. `auto_borrow` and `auto_repay` cannot be both set to true in one order.  # noqa: E501

        :return: The auto_repay of this Order.  # noqa: E501
        :rtype: bool
        """
        return self._auto_repay

    @auto_repay.setter
    def auto_repay(self, auto_repay):
        """Sets the auto_repay of this Order.

        Enable or disable automatic repayment for automatic borrow loan generated by cross margin order. Default is disabled. Note that:  1. This field is only effective for cross margin orders. Margin account does not support setting auto repayment for orders. 2. `auto_borrow` and `auto_repay` cannot be both set to true in one order.  # noqa: E501

        :param auto_repay: The auto_repay of this Order.  # noqa: E501
        :type: bool
        """

        self._auto_repay = auto_repay

    @property
    def left(self):
        """Gets the left of this Order.  # noqa: E501

        Amount left to fill  # noqa: E501

        :return: The left of this Order.  # noqa: E501
        :rtype: str
        """
        return self._left

    @left.setter
    def left(self, left):
        """Sets the left of this Order.

        Amount left to fill  # noqa: E501

        :param left: The left of this Order.  # noqa: E501
        :type: str
        """

        self._left = left

    @property
    def fill_price(self):
        """Gets the fill_price of this Order.  # noqa: E501

        Total filled in quote currency. Deprecated in favor of `filled_total`  # noqa: E501

        :return: The fill_price of this Order.  # noqa: E501
        :rtype: str
        """
        return self._fill_price

    @fill_price.setter
    def fill_price(self, fill_price):
        """Sets the fill_price of this Order.

        Total filled in quote currency. Deprecated in favor of `filled_total`  # noqa: E501

        :param fill_price: The fill_price of this Order.  # noqa: E501
        :type: str
        """

        self._fill_price = fill_price

    @property
    def filled_total(self):
        """Gets the filled_total of this Order.  # noqa: E501

        Total filled in quote currency  # noqa: E501

        :return: The filled_total of this Order.  # noqa: E501
        :rtype: str
        """
        return self._filled_total

    @filled_total.setter
    def filled_total(self, filled_total):
        """Sets the filled_total of this Order.

        Total filled in quote currency  # noqa: E501

        :param filled_total: The filled_total of this Order.  # noqa: E501
        :type: str
        """

        self._filled_total = filled_total

    @property
    def fee(self):
        """Gets the fee of this Order.  # noqa: E501

        Fee deducted  # noqa: E501

        :return: The fee of this Order.  # noqa: E501
        :rtype: str
        """
        return self._fee

    @fee.setter
    def fee(self, fee):
        """Sets the fee of this Order.

        Fee deducted  # noqa: E501

        :param fee: The fee of this Order.  # noqa: E501
        :type: str
        """

        self._fee = fee

    @property
    def fee_currency(self):
        """Gets the fee_currency of this Order.  # noqa: E501

        Fee currency unit  # noqa: E501

        :return: The fee_currency of this Order.  # noqa: E501
        :rtype: str
        """
        return self._fee_currency

    @fee_currency.setter
    def fee_currency(self, fee_currency):
        """Sets the fee_currency of this Order.

        Fee currency unit  # noqa: E501

        :param fee_currency: The fee_currency of this Order.  # noqa: E501
        :type: str
        """

        self._fee_currency = fee_currency

    @property
    def point_fee(self):
        """Gets the point_fee of this Order.  # noqa: E501

        Points used to deduct fee  # noqa: E501

        :return: The point_fee of this Order.  # noqa: E501
        :rtype: str
        """
        return self._point_fee

    @point_fee.setter
    def point_fee(self, point_fee):
        """Sets the point_fee of this Order.

        Points used to deduct fee  # noqa: E501

        :param point_fee: The point_fee of this Order.  # noqa: E501
        :type: str
        """

        self._point_fee = point_fee

    @property
    def gt_fee(self):
        """Gets the gt_fee of this Order.  # noqa: E501

        GT used to deduct fee  # noqa: E501

        :return: The gt_fee of this Order.  # noqa: E501
        :rtype: str
        """
        return self._gt_fee

    @gt_fee.setter
    def gt_fee(self, gt_fee):
        """Sets the gt_fee of this Order.

        GT used to deduct fee  # noqa: E501

        :param gt_fee: The gt_fee of this Order.  # noqa: E501
        :type: str
        """

        self._gt_fee = gt_fee

    @property
    def gt_discount(self):
        """Gets the gt_discount of this Order.  # noqa: E501

        Whether GT fee discount is used  # noqa: E501

        :return: The gt_discount of this Order.  # noqa: E501
        :rtype: bool
        """
        return self._gt_discount

    @gt_discount.setter
    def gt_discount(self, gt_discount):
        """Sets the gt_discount of this Order.

        Whether GT fee discount is used  # noqa: E501

        :param gt_discount: The gt_discount of this Order.  # noqa: E501
        :type: bool
        """

        self._gt_discount = gt_discount

    @property
    def rebated_fee(self):
        """Gets the rebated_fee of this Order.  # noqa: E501

        Rebated fee  # noqa: E501

        :return: The rebated_fee of this Order.  # noqa: E501
        :rtype: str
        """
        return self._rebated_fee

    @rebated_fee.setter
    def rebated_fee(self, rebated_fee):
        """Sets the rebated_fee of this Order.

        Rebated fee  # noqa: E501

        :param rebated_fee: The rebated_fee of this Order.  # noqa: E501
        :type: str
        """

        self._rebated_fee = rebated_fee

    @property
    def rebated_fee_currency(self):
        """Gets the rebated_fee_currency of this Order.  # noqa: E501

        Rebated fee currency unit  # noqa: E501

        :return: The rebated_fee_currency of this Order.  # noqa: E501
        :rtype: str
        """
        return self._rebated_fee_currency

    @rebated_fee_currency.setter
    def rebated_fee_currency(self, rebated_fee_currency):
        """Sets the rebated_fee_currency of this Order.

        Rebated fee currency unit  # noqa: E501

        :param rebated_fee_currency: The rebated_fee_currency of this Order.  # noqa: E501
        :type: str
        """

        self._rebated_fee_currency = rebated_fee_currency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Order):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Order):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class Ticker(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'currency_pair': 'str',
        'last': 'str',
        'lowest_ask': 'str',
        'highest_bid': 'str',
        'change_percentage': 'str',
        'base_volume': 'str',
        'quote_volume': 'str',
        'high_24h': 'str',
        'low_24h': 'str',
        'etf_net_value': 'str',
        'etf_pre_net_value': 'str',
        'etf_pre_timestamp': 'int',
        'etf_leverage': 'str',
    }

    attribute_map = {
        'currency_pair': 'currency_pair',
        'last': 'last',
        'lowest_ask': 'lowest_ask',
        'highest_bid': 'highest_bid',
        'change_percentage': 'change_percentage',
        'base_volume': 'base_volume',
        'quote_volume': 'quote_volume',
        'high_24h': 'high_24h',
        'low_24h': 'low_24h',
        'etf_net_value': 'etf_net_value',
        'etf_pre_net_value': 'etf_pre_net_value',
        'etf_pre_timestamp': 'etf_pre_timestamp',
        'etf_leverage': 'etf_leverage',
    }

    def __init__(
        self,
        currency_pair=None,
        last=None,
        lowest_ask=None,
        highest_bid=None,
        change_percentage=None,
        base_volume=None,
        quote_volume=None,
        high_24h=None,
        low_24h=None,
        etf_net_value=None,
        etf_pre_net_value=None,
        etf_pre_timestamp=None,
        etf_leverage=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (str, str, str, str, str, str, str, str, str, str, str, int, str, Configuration) -> None
        """Ticker - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._currency_pair = None
        self._last = None
        self._lowest_ask = None
        self._highest_bid = None
        self._change_percentage = None
        self._base_volume = None
        self._quote_volume = None
        self._high_24h = None
        self._low_24h = None
        self._etf_net_value = None
        self._etf_pre_net_value = None
        self._etf_pre_timestamp = None
        self._etf_leverage = None
        self.discriminator = None

        if currency_pair is not None:
            self.currency_pair = currency_pair
        if last is not None:
            self.last = last
        if lowest_ask is not None:
            self.lowest_ask = lowest_ask
        if highest_bid is not None:
            self.highest_bid = highest_bid
        if change_percentage is not None:
            self.change_percentage = change_percentage
        if base_volume is not None:
            self.base_volume = base_volume
        if quote_volume is not None:
            self.quote_volume = quote_volume
        if high_24h is not None:
            self.high_24h = high_24h
        if low_24h is not None:
            self.low_24h = low_24h
        if etf_net_value is not None:
            self.etf_net_value = etf_net_value
        self.etf_pre_net_value = etf_pre_net_value
        self.etf_pre_timestamp = etf_pre_timestamp
        self.etf_leverage = etf_leverage

    @property
    def currency_pair(self):
        """Gets the currency_pair of this Ticker.  # noqa: E501

        Currency pair  # noqa: E501

        :return: The currency_pair of this Ticker.  # noqa: E501
        :rtype: str
        """
        return self._currency_pair

    @currency_pair.setter
    def currency_pair(self, currency_pair):
        """Sets the currency_pair of this Ticker.

        Currency pair  # noqa: E501

        :param currency_pair: The currency_pair of this Ticker.  # noqa: E501
        :type: str
        """

        self._currency_pair = currency_pair

    @property
    def last(self):
        """Gets the last of this Ticker.  # noqa: E501

        Last trading price  # noqa: E501

        :return: The last of this Ticker.  # noqa: E501
        :rtype: str
        """
        return self._last

    @last.setter
    def last(self, last):
        """Sets the last of this Ticker.

        Last trading price  # noqa: E501

        :param last: The last of this Ticker.  # noqa: E501
        :type: str
        """

        self._last = last

    @property
    def lowest_ask(self):
        """Gets the lowest_ask of this Ticker.  # noqa: E501

        Lowest ask  # noqa: E501

        :return: The lowest_ask of this Ticker.  # noqa: E501
        :rtype: str
        """
        return self._lowest_ask

    @lowest_ask.setter
    def lowest_ask(self, lowest_ask):
        """Sets the lowest_ask of this Ticker.

        Lowest ask  # noqa: E501

        :param lowest_ask: The lowest_ask of this Ticker.  # noqa: E501
        :type: str
        """

        self._lowest_ask = lowest_ask

    @property
    def highest_bid(self):
        """Gets the highest_bid of this Ticker.  # noqa: E501

        Highest bid  # noqa: E501

        :return: The highest_bid of this Ticker.  # noqa: E501
        :rtype: str
        """
        return self._highest_bid

    @highest_bid.setter
    def highest_bid(self, highest_bid):
        """Sets the highest_bid of this Ticker.

        Highest bid  # noqa: E501

        :param highest_bid: The highest_bid of this Ticker.  # noqa: E501
        :type: str
        """

        self._highest_bid = highest_bid

    @property
    def change_percentage(self):
        """Gets the change_percentage of this Ticker.  # noqa: E501

        Change percentage.  # noqa: E501

        :return: The change_percentage of this Ticker.  # noqa: E501
        :rtype: str
        """
        return self._change_percentage

    @change_percentage.setter
    def change_percentage(self, change_percentage):
        """Sets the change_percentage of this Ticker.

        Change percentage.  # noqa: E501

        :param change_percentage: The change_percentage of this Ticker.  # noqa: E501
        :type: str
        """

        self._change_percentage = change_percentage

    @property
    def base_volume(self):
        """Gets the base_volume of this Ticker.  # noqa: E501

        Base currency trade volume  # noqa: E501

        :return: The base_volume of this Ticker.  # noqa: E501
        :rtype: str
        """
        return self._base_volume

    @base_volume.setter
    def base_volume(self, base_volume):
        """Sets the base_volume of this Ticker.

        Base currency trade volume  # noqa: E501

        :param base_volume: The base_volume of this Ticker.  # noqa: E501
        :type: str
        """

        self._base_volume = base_volume

    @property
    def quote_volume(self):
        """Gets the quote_volume of this Ticker.  # noqa: E501

        Quote currency trade volume  # noqa: E501

        :return: The quote_volume of this Ticker.  # noqa: E501
        :rtype: str
        """
        return self._quote_volume

    @quote_volume.setter
    def quote_volume(self, quote_volume):
        """Sets the quote_volume of this Ticker.

        Quote currency trade volume  # noqa: E501

        :param quote_volume: The quote_volume of this Ticker.  # noqa: E501
        :type: str
        """

        self._quote_volume = quote_volume

    @property
    def high_24h(self):
        """Gets the high_24h of this Ticker.  # noqa: E501

        Highest price in 24h  # noqa: E501

        :return: The high_24h of this Ticker.  # noqa: E501
        :rtype: str
        """
        return self._high_24h

    @high_24h.setter
    def high_24h(self, high_24h):
        """Sets the high_24h of this Ticker.

        Highest price in 24h  # noqa: E501

        :param high_24h: The high_24h of this Ticker.  # noqa: E501
        :type: str
        """

        self._high_24h = high_24h

    @property
    def low_24h(self):
        """Gets the low_24h of this Ticker.  # noqa: E501

        Lowest price in 24h  # noqa: E501

        :return: The low_24h of this Ticker.  # noqa: E501
        :rtype: str
        """
        return self._low_24h

    @low_24h.setter
    def low_24h(self, low_24h):
        """Sets the low_24h of this Ticker.

        Lowest price in 24h  # noqa: E501

        :param low_24h: The low_24h of this Ticker.  # noqa: E501
        :type: str
        """

        self._low_24h = low_24h

    @property
    def etf_net_value(self):
        """Gets the etf_net_value of this Ticker.  # noqa: E501

        ETF net value  # noqa: E501

        :return: The etf_net_value of this Ticker.  # noqa: E501
        :rtype: str
        """
        return self._etf_net_value

    @etf_net_value.setter
    def etf_net_value(self, etf_net_value):
        """Sets the etf_net_value of this Ticker.

        ETF net value  # noqa: E501

        :param etf_net_value: The etf_net_value of this Ticker.  # noqa: E501
        :type: str
        """

        self._etf_net_value = etf_net_value

    @property
    def etf_pre_net_value(self):
        """Gets the etf_pre_net_value of this Ticker.  # noqa: E501

        ETF previous net value at re-balancing time  # noqa: E501

        :return: The etf_pre_net_value of this Ticker.  # noqa: E501
        :rtype: str
        """
        return self._etf_pre_net_value

    @etf_pre_net_value.setter
    def etf_pre_net_value(self, etf_pre_net_value):
        """Sets the etf_pre_net_value of this Ticker.

        ETF previous net value at re-balancing time  # noqa: E501

        :param etf_pre_net_value: The etf_pre_net_value of this Ticker.  # noqa: E501
        :type: str
        """

        self._etf_pre_net_value = etf_pre_net_value

    @property
    def etf_pre_timestamp(self):
        """Gets the etf_pre_timestamp of this Ticker.  # noqa: E501

        ETF previous re-balancing time  # noqa: E501

        :return: The etf_pre_timestamp of this Ticker.  # noqa: E501
        :rtype: int
        """
        return self._etf_pre_timestamp

    @etf_pre_timestamp.setter
    def etf_pre_timestamp(self, etf_pre_timestamp):
        """Sets the etf_pre_timestamp of this Ticker.

        ETF previous re-balancing time  # noqa: E501

        :param etf_pre_timestamp: The etf_pre_timestamp of this Ticker.  # noqa: E501
        :type: int
        """

        self._etf_pre_timestamp = etf_pre_timestamp

    @property
    def etf_leverage(self):
        """Gets the etf_leverage of this Ticker.  # noqa: E501

        ETF current leverage  # noqa: E501

        :return: The etf_leverage of this Ticker.  # noqa: E501
        :rtype: str
        """
        return self._etf_leverage

    @etf_leverage.setter
    def etf_leverage(self, etf_leverage):
        """Sets the etf_leverage of this Ticker.

        ETF current leverage  # noqa: E501

        :param etf_leverage: The etf_leverage of this Ticker.  # noqa: E501
        :type: str
        """

        self._etf_leverage = etf_leverage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Ticker):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Ticker):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class CrossMarginBorrowable(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {'currency': 'str', 'amount': 'str'}

    attribute_map = {'currency': 'currency', 'amount': 'amount'}

    def __init__(self, currency=None, amount=None, local_vars_configuration=None):  # noqa: E501
        # type: (str, str, Configuration) -> None
        """CrossMarginBorrowable - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._currency = None
        self._amount = None
        self.discriminator = None

        if currency is not None:
            self.currency = currency
        if amount is not None:
            self.amount = amount

    @property
    def currency(self):
        """Gets the currency of this CrossMarginBorrowable.  # noqa: E501

        Currency detail  # noqa: E501

        :return: The currency of this CrossMarginBorrowable.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this CrossMarginBorrowable.

        Currency detail  # noqa: E501

        :param currency: The currency of this CrossMarginBorrowable.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def amount(self):
        """Gets the amount of this CrossMarginBorrowable.  # noqa: E501

        Max borrowable amount  # noqa: E501

        :return: The amount of this CrossMarginBorrowable.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this CrossMarginBorrowable.

        Max borrowable amount  # noqa: E501

        :param amount: The amount of this CrossMarginBorrowable.  # noqa: E501
        :type: str
        """

        self._amount = amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CrossMarginBorrowable):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CrossMarginBorrowable):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class OptionsTicker(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'last_price': 'str',
        'mark_price': 'str',
        'index_price': 'str',
        'ask1_size': 'int',
        'ask1_price': 'str',
        'bid1_size': 'int',
        'bid1_price': 'str',
        'position_size': 'int',
        'mark_iv': 'str',
        'bid_iv': 'str',
        'ask_iv': 'str',
        'leverage': 'str',
        'delta': 'str',
        'gamma': 'str',
        'vega': 'str',
        'theta': 'str',
        'rho': 'str',
    }

    attribute_map = {
        'name': 'name',
        'last_price': 'last_price',
        'mark_price': 'mark_price',
        'index_price': 'index_price',
        'ask1_size': 'ask1_size',
        'ask1_price': 'ask1_price',
        'bid1_size': 'bid1_size',
        'bid1_price': 'bid1_price',
        'position_size': 'position_size',
        'mark_iv': 'mark_iv',
        'bid_iv': 'bid_iv',
        'ask_iv': 'ask_iv',
        'leverage': 'leverage',
        'delta': 'delta',
        'gamma': 'gamma',
        'vega': 'vega',
        'theta': 'theta',
        'rho': 'rho',
    }

    def __init__(
        self,
        name=None,
        last_price=None,
        mark_price=None,
        index_price=None,
        ask1_size=None,
        ask1_price=None,
        bid1_size=None,
        bid1_price=None,
        position_size=None,
        mark_iv=None,
        bid_iv=None,
        ask_iv=None,
        leverage=None,
        delta=None,
        gamma=None,
        vega=None,
        theta=None,
        rho=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (str, str, str, str, int, str, int, str, int, str, str, str, str, str, str, str, str, str, Configuration) -> None
        """OptionsTicker - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._last_price = None
        self._mark_price = None
        self._index_price = None
        self._ask1_size = None
        self._ask1_price = None
        self._bid1_size = None
        self._bid1_price = None
        self._position_size = None
        self._mark_iv = None
        self._bid_iv = None
        self._ask_iv = None
        self._leverage = None
        self._delta = None
        self._gamma = None
        self._vega = None
        self._theta = None
        self._rho = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if last_price is not None:
            self.last_price = last_price
        if mark_price is not None:
            self.mark_price = mark_price
        if index_price is not None:
            self.index_price = index_price
        if ask1_size is not None:
            self.ask1_size = ask1_size
        if ask1_price is not None:
            self.ask1_price = ask1_price
        if bid1_size is not None:
            self.bid1_size = bid1_size
        if bid1_price is not None:
            self.bid1_price = bid1_price
        if position_size is not None:
            self.position_size = position_size
        if mark_iv is not None:
            self.mark_iv = mark_iv
        if bid_iv is not None:
            self.bid_iv = bid_iv
        if ask_iv is not None:
            self.ask_iv = ask_iv
        if leverage is not None:
            self.leverage = leverage
        if delta is not None:
            self.delta = delta
        if gamma is not None:
            self.gamma = gamma
        if vega is not None:
            self.vega = vega
        if theta is not None:
            self.theta = theta
        if rho is not None:
            self.rho = rho

    @property
    def name(self):
        """Gets the name of this OptionsTicker.  # noqa: E501

        Options contract name  # noqa: E501

        :return: The name of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OptionsTicker.

        Options contract name  # noqa: E501

        :param name: The name of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def last_price(self):
        """Gets the last_price of this OptionsTicker.  # noqa: E501

        Last trading price  # noqa: E501

        :return: The last_price of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._last_price

    @last_price.setter
    def last_price(self, last_price):
        """Sets the last_price of this OptionsTicker.

        Last trading price  # noqa: E501

        :param last_price: The last_price of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._last_price = last_price

    @property
    def mark_price(self):
        """Gets the mark_price of this OptionsTicker.  # noqa: E501

        Current mark price  # noqa: E501

        :return: The mark_price of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._mark_price

    @mark_price.setter
    def mark_price(self, mark_price):
        """Sets the mark_price of this OptionsTicker.

        Current mark price  # noqa: E501

        :param mark_price: The mark_price of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._mark_price = mark_price

    @property
    def index_price(self):
        """Gets the index_price of this OptionsTicker.  # noqa: E501

        Current index price  # noqa: E501

        :return: The index_price of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._index_price

    @index_price.setter
    def index_price(self, index_price):
        """Sets the index_price of this OptionsTicker.

        Current index price  # noqa: E501

        :param index_price: The index_price of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._index_price = index_price

    @property
    def ask1_size(self):
        """Gets the ask1_size of this OptionsTicker.  # noqa: E501

        Best ask size  # noqa: E501

        :return: The ask1_size of this OptionsTicker.  # noqa: E501
        :rtype: int
        """
        return self._ask1_size

    @ask1_size.setter
    def ask1_size(self, ask1_size):
        """Sets the ask1_size of this OptionsTicker.

        Best ask size  # noqa: E501

        :param ask1_size: The ask1_size of this OptionsTicker.  # noqa: E501
        :type: int
        """

        self._ask1_size = ask1_size

    @property
    def ask1_price(self):
        """Gets the ask1_price of this OptionsTicker.  # noqa: E501

        Best ask price  # noqa: E501

        :return: The ask1_price of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._ask1_price

    @ask1_price.setter
    def ask1_price(self, ask1_price):
        """Sets the ask1_price of this OptionsTicker.

        Best ask price  # noqa: E501

        :param ask1_price: The ask1_price of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._ask1_price = ask1_price

    @property
    def bid1_size(self):
        """Gets the bid1_size of this OptionsTicker.  # noqa: E501

        Best bid size  # noqa: E501

        :return: The bid1_size of this OptionsTicker.  # noqa: E501
        :rtype: int
        """
        return self._bid1_size

    @bid1_size.setter
    def bid1_size(self, bid1_size):
        """Sets the bid1_size of this OptionsTicker.

        Best bid size  # noqa: E501

        :param bid1_size: The bid1_size of this OptionsTicker.  # noqa: E501
        :type: int
        """

        self._bid1_size = bid1_size

    @property
    def bid1_price(self):
        """Gets the bid1_price of this OptionsTicker.  # noqa: E501

        Best bid price  # noqa: E501

        :return: The bid1_price of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._bid1_price

    @bid1_price.setter
    def bid1_price(self, bid1_price):
        """Sets the bid1_price of this OptionsTicker.

        Best bid price  # noqa: E501

        :param bid1_price: The bid1_price of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._bid1_price = bid1_price

    @property
    def position_size(self):
        """Gets the position_size of this OptionsTicker.  # noqa: E501

        Current total long position size  # noqa: E501

        :return: The position_size of this OptionsTicker.  # noqa: E501
        :rtype: int
        """
        return self._position_size

    @position_size.setter
    def position_size(self, position_size):
        """Sets the position_size of this OptionsTicker.

        Current total long position size  # noqa: E501

        :param position_size: The position_size of this OptionsTicker.  # noqa: E501
        :type: int
        """

        self._position_size = position_size

    @property
    def mark_iv(self):
        """Gets the mark_iv of this OptionsTicker.  # noqa: E501

        Implied volatility  # noqa: E501

        :return: The mark_iv of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._mark_iv

    @mark_iv.setter
    def mark_iv(self, mark_iv):
        """Sets the mark_iv of this OptionsTicker.

        Implied volatility  # noqa: E501

        :param mark_iv: The mark_iv of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._mark_iv = mark_iv

    @property
    def bid_iv(self):
        """Gets the bid_iv of this OptionsTicker.  # noqa: E501

        Bid side implied volatility  # noqa: E501

        :return: The bid_iv of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._bid_iv

    @bid_iv.setter
    def bid_iv(self, bid_iv):
        """Sets the bid_iv of this OptionsTicker.

        Bid side implied volatility  # noqa: E501

        :param bid_iv: The bid_iv of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._bid_iv = bid_iv

    @property
    def ask_iv(self):
        """Gets the ask_iv of this OptionsTicker.  # noqa: E501

        Ask side implied volatility  # noqa: E501

        :return: The ask_iv of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._ask_iv

    @ask_iv.setter
    def ask_iv(self, ask_iv):
        """Sets the ask_iv of this OptionsTicker.

        Ask side implied volatility  # noqa: E501

        :param ask_iv: The ask_iv of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._ask_iv = ask_iv

    @property
    def leverage(self):
        """Gets the leverage of this OptionsTicker.  # noqa: E501

        Current leverage. Formula: underlying_price / mark_price * delta  # noqa: E501

        :return: The leverage of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._leverage

    @leverage.setter
    def leverage(self, leverage):
        """Sets the leverage of this OptionsTicker.

        Current leverage. Formula: underlying_price / mark_price * delta  # noqa: E501

        :param leverage: The leverage of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._leverage = leverage

    @property
    def delta(self):
        """Gets the delta of this OptionsTicker.  # noqa: E501

        Delta  # noqa: E501

        :return: The delta of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._delta

    @delta.setter
    def delta(self, delta):
        """Sets the delta of this OptionsTicker.

        Delta  # noqa: E501

        :param delta: The delta of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._delta = delta

    @property
    def gamma(self):
        """Gets the gamma of this OptionsTicker.  # noqa: E501

        Gamma  # noqa: E501

        :return: The gamma of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._gamma

    @gamma.setter
    def gamma(self, gamma):
        """Sets the gamma of this OptionsTicker.

        Gamma  # noqa: E501

        :param gamma: The gamma of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._gamma = gamma

    @property
    def vega(self):
        """Gets the vega of this OptionsTicker.  # noqa: E501

        Vega  # noqa: E501

        :return: The vega of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._vega

    @vega.setter
    def vega(self, vega):
        """Sets the vega of this OptionsTicker.

        Vega  # noqa: E501

        :param vega: The vega of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._vega = vega

    @property
    def theta(self):
        """Gets the theta of this OptionsTicker.  # noqa: E501

        Theta  # noqa: E501

        :return: The theta of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._theta

    @theta.setter
    def theta(self, theta):
        """Sets the theta of this OptionsTicker.

        Theta  # noqa: E501

        :param theta: The theta of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._theta = theta

    @property
    def rho(self):
        """Gets the rho of this OptionsTicker.  # noqa: E501

        Rho  # noqa: E501

        :return: The rho of this OptionsTicker.  # noqa: E501
        :rtype: str
        """
        return self._rho

    @rho.setter
    def rho(self, rho):
        """Sets the rho of this OptionsTicker.

        Rho  # noqa: E501

        :param rho: The rho of this OptionsTicker.  # noqa: E501
        :type: str
        """

        self._rho = rho

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OptionsTicker):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OptionsTicker):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from gate_api.api.delivery_api import DeliveryApi
from gate_api.api.futures_api import FuturesApi
from gate_api.api.margin_api import MarginApi
from gate_api.api.options_api import OptionsApi
from gate_api.api.spot_api import SpotApi
from gate_api.api.wallet_api import WalletApi
from gate_api.api.withdrawal_api import WithdrawalApi



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class TradeFee(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'int',
        'taker_fee': 'str',
        'maker_fee': 'str',
        'gt_discount': 'bool',
        'gt_taker_fee': 'str',
        'gt_maker_fee': 'str',
        'loan_fee': 'str',
        'point_type': 'str',
        'futures_taker_fee': 'str',
        'futures_maker_fee': 'str',
    }

    attribute_map = {
        'user_id': 'user_id',
        'taker_fee': 'taker_fee',
        'maker_fee': 'maker_fee',
        'gt_discount': 'gt_discount',
        'gt_taker_fee': 'gt_taker_fee',
        'gt_maker_fee': 'gt_maker_fee',
        'loan_fee': 'loan_fee',
        'point_type': 'point_type',
        'futures_taker_fee': 'futures_taker_fee',
        'futures_maker_fee': 'futures_maker_fee',
    }

    def __init__(
        self,
        user_id=None,
        taker_fee=None,
        maker_fee=None,
        gt_discount=None,
        gt_taker_fee=None,
        gt_maker_fee=None,
        loan_fee=None,
        point_type=None,
        futures_taker_fee=None,
        futures_maker_fee=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (int, str, str, bool, str, str, str, str, str, str, Configuration) -> None
        """TradeFee - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._taker_fee = None
        self._maker_fee = None
        self._gt_discount = None
        self._gt_taker_fee = None
        self._gt_maker_fee = None
        self._loan_fee = None
        self._point_type = None
        self._futures_taker_fee = None
        self._futures_maker_fee = None
        self.discriminator = None

        if user_id is not None:
            self.user_id = user_id
        if taker_fee is not None:
            self.taker_fee = taker_fee
        if maker_fee is not None:
            self.maker_fee = maker_fee
        if gt_discount is not None:
            self.gt_discount = gt_discount
        if gt_taker_fee is not None:
            self.gt_taker_fee = gt_taker_fee
        if gt_maker_fee is not None:
            self.gt_maker_fee = gt_maker_fee
        if loan_fee is not None:
            self.loan_fee = loan_fee
        if point_type is not None:
            self.point_type = point_type
        if futures_taker_fee is not None:
            self.futures_taker_fee = futures_taker_fee
        if futures_maker_fee is not None:
            self.futures_maker_fee = futures_maker_fee

    @property
    def user_id(self):
        """Gets the user_id of this TradeFee.  # noqa: E501

        User ID  # noqa: E501

        :return: The user_id of this TradeFee.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this TradeFee.

        User ID  # noqa: E501

        :param user_id: The user_id of this TradeFee.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    @property
    def taker_fee(self):
        """Gets the taker_fee of this TradeFee.  # noqa: E501

        taker fee rate  # noqa: E501

        :return: The taker_fee of this TradeFee.  # noqa: E501
        :rtype: str
        """
        return self._taker_fee

    @taker_fee.setter
    def taker_fee(self, taker_fee):
        """Sets the taker_fee of this TradeFee.

        taker fee rate  # noqa: E501

        :param taker_fee: The taker_fee of this TradeFee.  # noqa: E501
        :type: str
        """

        self._taker_fee = taker_fee

    @property
    def maker_fee(self):
        """Gets the maker_fee of this TradeFee.  # noqa: E501

        maker fee rate  # noqa: E501

        :return: The maker_fee of this TradeFee.  # noqa: E501
        :rtype: str
        """
        return self._maker_fee

    @maker_fee.setter
    def maker_fee(self, maker_fee):
        """Sets the maker_fee of this TradeFee.

        maker fee rate  # noqa: E501

        :param maker_fee: The maker_fee of this TradeFee.  # noqa: E501
        :type: str
        """

        self._maker_fee = maker_fee

    @property
    def gt_discount(self):
        """Gets the gt_discount of this TradeFee.  # noqa: E501

        If GT deduction is enabled  # noqa: E501

        :return: The gt_discount of this TradeFee.  # noqa: E501
        :rtype: bool
        """
        return self._gt_discount

    @gt_discount.setter
    def gt_discount(self, gt_discount):
        """Sets the gt_discount of this TradeFee.

        If GT deduction is enabled  # noqa: E501

        :param gt_discount: The gt_discount of this TradeFee.  # noqa: E501
        :type: bool
        """

        self._gt_discount = gt_discount

    @property
    def gt_taker_fee(self):
        """Gets the gt_taker_fee of this TradeFee.  # noqa: E501

        Taker fee rate if using GT deduction. It will be 0 if GT deduction is disabled  # noqa: E501

        :return: The gt_taker_fee of this TradeFee.  # noqa: E501
        :rtype: str
        """
        return self._gt_taker_fee

    @gt_taker_fee.setter
    def gt_taker_fee(self, gt_taker_fee):
        """Sets the gt_taker_fee of this TradeFee.

        Taker fee rate if using GT deduction. It will be 0 if GT deduction is disabled  # noqa: E501

        :param gt_taker_fee: The gt_taker_fee of this TradeFee.  # noqa: E501
        :type: str
        """

        self._gt_taker_fee = gt_taker_fee

    @property
    def gt_maker_fee(self):
        """Gets the gt_maker_fee of this TradeFee.  # noqa: E501

        Maker fee rate if using GT deduction. It will be 0 if GT deduction is disabled  # noqa: E501

        :return: The gt_maker_fee of this TradeFee.  # noqa: E501
        :rtype: str
        """
        return self._gt_maker_fee

    @gt_maker_fee.setter
    def gt_maker_fee(self, gt_maker_fee):
        """Sets the gt_maker_fee of this TradeFee.

        Maker fee rate if using GT deduction. It will be 0 if GT deduction is disabled  # noqa: E501

        :param gt_maker_fee: The gt_maker_fee of this TradeFee.  # noqa: E501
        :type: str
        """

        self._gt_maker_fee = gt_maker_fee

    @property
    def loan_fee(self):
        """Gets the loan_fee of this TradeFee.  # noqa: E501

        Loan fee rate of margin lending  # noqa: E501

        :return: The loan_fee of this TradeFee.  # noqa: E501
        :rtype: str
        """
        return self._loan_fee

    @loan_fee.setter
    def loan_fee(self, loan_fee):
        """Sets the loan_fee of this TradeFee.

        Loan fee rate of margin lending  # noqa: E501

        :param loan_fee: The loan_fee of this TradeFee.  # noqa: E501
        :type: str
        """

        self._loan_fee = loan_fee

    @property
    def point_type(self):
        """Gets the point_type of this TradeFee.  # noqa: E501

        Point type. 0 - Initial version. 1 - new version since 202009  # noqa: E501

        :return: The point_type of this TradeFee.  # noqa: E501
        :rtype: str
        """
        return self._point_type

    @point_type.setter
    def point_type(self, point_type):
        """Sets the point_type of this TradeFee.

        Point type. 0 - Initial version. 1 - new version since 202009  # noqa: E501

        :param point_type: The point_type of this TradeFee.  # noqa: E501
        :type: str
        """

        self._point_type = point_type

    @property
    def futures_taker_fee(self):
        """Gets the futures_taker_fee of this TradeFee.  # noqa: E501

        Futures trading taker fee  # noqa: E501

        :return: The futures_taker_fee of this TradeFee.  # noqa: E501
        :rtype: str
        """
        return self._futures_taker_fee

    @futures_taker_fee.setter
    def futures_taker_fee(self, futures_taker_fee):
        """Sets the futures_taker_fee of this TradeFee.

        Futures trading taker fee  # noqa: E501

        :param futures_taker_fee: The futures_taker_fee of this TradeFee.  # noqa: E501
        :type: str
        """

        self._futures_taker_fee = futures_taker_fee

    @property
    def futures_maker_fee(self):
        """Gets the futures_maker_fee of this TradeFee.  # noqa: E501

        Future trading maker fee  # noqa: E501

        :return: The futures_maker_fee of this TradeFee.  # noqa: E501
        :rtype: str
        """
        return self._futures_maker_fee

    @futures_maker_fee.setter
    def futures_maker_fee(self, futures_maker_fee):
        """Sets the futures_maker_fee of this TradeFee.

        Future trading maker fee  # noqa: E501

        :param futures_maker_fee: The futures_maker_fee of this TradeFee.  # noqa: E501
        :type: str
        """

        self._futures_maker_fee = futures_maker_fee

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TradeFee):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TradeFee):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class FuturesTicker(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'contract': 'str',
        'last': 'str',
        'change_percentage': 'str',
        'total_size': 'str',
        'low_24h': 'str',
        'high_24h': 'str',
        'volume_24h': 'str',
        'volume_24h_btc': 'str',
        'volume_24h_usd': 'str',
        'volume_24h_base': 'str',
        'volume_24h_quote': 'str',
        'volume_24h_settle': 'str',
        'mark_price': 'str',
        'funding_rate': 'str',
        'funding_rate_indicative': 'str',
        'index_price': 'str',
        'quanto_base_rate': 'str',
    }

    attribute_map = {
        'contract': 'contract',
        'last': 'last',
        'change_percentage': 'change_percentage',
        'total_size': 'total_size',
        'low_24h': 'low_24h',
        'high_24h': 'high_24h',
        'volume_24h': 'volume_24h',
        'volume_24h_btc': 'volume_24h_btc',
        'volume_24h_usd': 'volume_24h_usd',
        'volume_24h_base': 'volume_24h_base',
        'volume_24h_quote': 'volume_24h_quote',
        'volume_24h_settle': 'volume_24h_settle',
        'mark_price': 'mark_price',
        'funding_rate': 'funding_rate',
        'funding_rate_indicative': 'funding_rate_indicative',
        'index_price': 'index_price',
        'quanto_base_rate': 'quanto_base_rate',
    }

    def __init__(
        self,
        contract=None,
        last=None,
        change_percentage=None,
        total_size=None,
        low_24h=None,
        high_24h=None,
        volume_24h=None,
        volume_24h_btc=None,
        volume_24h_usd=None,
        volume_24h_base=None,
        volume_24h_quote=None,
        volume_24h_settle=None,
        mark_price=None,
        funding_rate=None,
        funding_rate_indicative=None,
        index_price=None,
        quanto_base_rate=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (str, str, str, str, str, str, str, str, str, str, str, str, str, str, str, str, str, Configuration) -> None
        """FuturesTicker - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._contract = None
        self._last = None
        self._change_percentage = None
        self._total_size = None
        self._low_24h = None
        self._high_24h = None
        self._volume_24h = None
        self._volume_24h_btc = None
        self._volume_24h_usd = None
        self._volume_24h_base = None
        self._volume_24h_quote = None
        self._volume_24h_settle = None
        self._mark_price = None
        self._funding_rate = None
        self._funding_rate_indicative = None
        self._index_price = None
        self._quanto_base_rate = None
        self.discriminator = None

        if contract is not None:
            self.contract = contract
        if last is not None:
            self.last = last
        if change_percentage is not None:
            self.change_percentage = change_percentage
        if total_size is not None:
            self.total_size = total_size
        if low_24h is not None:
            self.low_24h = low_24h
        if high_24h is not None:
            self.high_24h = high_24h
        if volume_24h is not None:
            self.volume_24h = volume_24h
        if volume_24h_btc is not None:
            self.volume_24h_btc = volume_24h_btc
        if volume_24h_usd is not None:
            self.volume_24h_usd = volume_24h_usd
        if volume_24h_base is not None:
            self.volume_24h_base = volume_24h_base
        if volume_24h_quote is not None:
            self.volume_24h_quote = volume_24h_quote
        if volume_24h_settle is not None:
            self.volume_24h_settle = volume_24h_settle
        if mark_price is not None:
            self.mark_price = mark_price
        if funding_rate is not None:
            self.funding_rate = funding_rate
        if funding_rate_indicative is not None:
            self.funding_rate_indicative = funding_rate_indicative
        if index_price is not None:
            self.index_price = index_price
        if quanto_base_rate is not None:
            self.quanto_base_rate = quanto_base_rate

    @property
    def contract(self):
        """Gets the contract of this FuturesTicker.  # noqa: E501

        Futures contract  # noqa: E501

        :return: The contract of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._contract

    @contract.setter
    def contract(self, contract):
        """Sets the contract of this FuturesTicker.

        Futures contract  # noqa: E501

        :param contract: The contract of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._contract = contract

    @property
    def last(self):
        """Gets the last of this FuturesTicker.  # noqa: E501

        Last trading price  # noqa: E501

        :return: The last of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._last

    @last.setter
    def last(self, last):
        """Sets the last of this FuturesTicker.

        Last trading price  # noqa: E501

        :param last: The last of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._last = last

    @property
    def change_percentage(self):
        """Gets the change_percentage of this FuturesTicker.  # noqa: E501

        Change percentage.  # noqa: E501

        :return: The change_percentage of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._change_percentage

    @change_percentage.setter
    def change_percentage(self, change_percentage):
        """Sets the change_percentage of this FuturesTicker.

        Change percentage.  # noqa: E501

        :param change_percentage: The change_percentage of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._change_percentage = change_percentage

    @property
    def total_size(self):
        """Gets the total_size of this FuturesTicker.  # noqa: E501

        Contract total size  # noqa: E501

        :return: The total_size of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._total_size

    @total_size.setter
    def total_size(self, total_size):
        """Sets the total_size of this FuturesTicker.

        Contract total size  # noqa: E501

        :param total_size: The total_size of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._total_size = total_size

    @property
    def low_24h(self):
        """Gets the low_24h of this FuturesTicker.  # noqa: E501

        Lowest trading price in recent 24h  # noqa: E501

        :return: The low_24h of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._low_24h

    @low_24h.setter
    def low_24h(self, low_24h):
        """Sets the low_24h of this FuturesTicker.

        Lowest trading price in recent 24h  # noqa: E501

        :param low_24h: The low_24h of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._low_24h = low_24h

    @property
    def high_24h(self):
        """Gets the high_24h of this FuturesTicker.  # noqa: E501

        Highest trading price in recent 24h  # noqa: E501

        :return: The high_24h of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._high_24h

    @high_24h.setter
    def high_24h(self, high_24h):
        """Sets the high_24h of this FuturesTicker.

        Highest trading price in recent 24h  # noqa: E501

        :param high_24h: The high_24h of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._high_24h = high_24h

    @property
    def volume_24h(self):
        """Gets the volume_24h of this FuturesTicker.  # noqa: E501

        Trade size in recent 24h  # noqa: E501

        :return: The volume_24h of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._volume_24h

    @volume_24h.setter
    def volume_24h(self, volume_24h):
        """Sets the volume_24h of this FuturesTicker.

        Trade size in recent 24h  # noqa: E501

        :param volume_24h: The volume_24h of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._volume_24h = volume_24h

    @property
    def volume_24h_btc(self):
        """Gets the volume_24h_btc of this FuturesTicker.  # noqa: E501

        Trade volumes in recent 24h in BTC(deprecated, use `volume_24h_base`, `volume_24h_quote`, `volume_24h_settle` instead)  # noqa: E501

        :return: The volume_24h_btc of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._volume_24h_btc

    @volume_24h_btc.setter
    def volume_24h_btc(self, volume_24h_btc):
        """Sets the volume_24h_btc of this FuturesTicker.

        Trade volumes in recent 24h in BTC(deprecated, use `volume_24h_base`, `volume_24h_quote`, `volume_24h_settle` instead)  # noqa: E501

        :param volume_24h_btc: The volume_24h_btc of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._volume_24h_btc = volume_24h_btc

    @property
    def volume_24h_usd(self):
        """Gets the volume_24h_usd of this FuturesTicker.  # noqa: E501

        Trade volumes in recent 24h in USD(deprecated, use `volume_24h_base`, `volume_24h_quote`, `volume_24h_settle` instead)  # noqa: E501

        :return: The volume_24h_usd of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._volume_24h_usd

    @volume_24h_usd.setter
    def volume_24h_usd(self, volume_24h_usd):
        """Sets the volume_24h_usd of this FuturesTicker.

        Trade volumes in recent 24h in USD(deprecated, use `volume_24h_base`, `volume_24h_quote`, `volume_24h_settle` instead)  # noqa: E501

        :param volume_24h_usd: The volume_24h_usd of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._volume_24h_usd = volume_24h_usd

    @property
    def volume_24h_base(self):
        """Gets the volume_24h_base of this FuturesTicker.  # noqa: E501

        Trade volume in recent 24h, in base currency  # noqa: E501

        :return: The volume_24h_base of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._volume_24h_base

    @volume_24h_base.setter
    def volume_24h_base(self, volume_24h_base):
        """Sets the volume_24h_base of this FuturesTicker.

        Trade volume in recent 24h, in base currency  # noqa: E501

        :param volume_24h_base: The volume_24h_base of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._volume_24h_base = volume_24h_base

    @property
    def volume_24h_quote(self):
        """Gets the volume_24h_quote of this FuturesTicker.  # noqa: E501

        Trade volume in recent 24h, in quote currency  # noqa: E501

        :return: The volume_24h_quote of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._volume_24h_quote

    @volume_24h_quote.setter
    def volume_24h_quote(self, volume_24h_quote):
        """Sets the volume_24h_quote of this FuturesTicker.

        Trade volume in recent 24h, in quote currency  # noqa: E501

        :param volume_24h_quote: The volume_24h_quote of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._volume_24h_quote = volume_24h_quote

    @property
    def volume_24h_settle(self):
        """Gets the volume_24h_settle of this FuturesTicker.  # noqa: E501

        Trade volume in recent 24h, in settle currency  # noqa: E501

        :return: The volume_24h_settle of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._volume_24h_settle

    @volume_24h_settle.setter
    def volume_24h_settle(self, volume_24h_settle):
        """Sets the volume_24h_settle of this FuturesTicker.

        Trade volume in recent 24h, in settle currency  # noqa: E501

        :param volume_24h_settle: The volume_24h_settle of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._volume_24h_settle = volume_24h_settle

    @property
    def mark_price(self):
        """Gets the mark_price of this FuturesTicker.  # noqa: E501

        Recent mark price  # noqa: E501

        :return: The mark_price of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._mark_price

    @mark_price.setter
    def mark_price(self, mark_price):
        """Sets the mark_price of this FuturesTicker.

        Recent mark price  # noqa: E501

        :param mark_price: The mark_price of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._mark_price = mark_price

    @property
    def funding_rate(self):
        """Gets the funding_rate of this FuturesTicker.  # noqa: E501

        Funding rate  # noqa: E501

        :return: The funding_rate of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._funding_rate

    @funding_rate.setter
    def funding_rate(self, funding_rate):
        """Sets the funding_rate of this FuturesTicker.

        Funding rate  # noqa: E501

        :param funding_rate: The funding_rate of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._funding_rate = funding_rate

    @property
    def funding_rate_indicative(self):
        """Gets the funding_rate_indicative of this FuturesTicker.  # noqa: E501

        Indicative Funding rate in next period  # noqa: E501

        :return: The funding_rate_indicative of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._funding_rate_indicative

    @funding_rate_indicative.setter
    def funding_rate_indicative(self, funding_rate_indicative):
        """Sets the funding_rate_indicative of this FuturesTicker.

        Indicative Funding rate in next period  # noqa: E501

        :param funding_rate_indicative: The funding_rate_indicative of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._funding_rate_indicative = funding_rate_indicative

    @property
    def index_price(self):
        """Gets the index_price of this FuturesTicker.  # noqa: E501

        Index price  # noqa: E501

        :return: The index_price of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._index_price

    @index_price.setter
    def index_price(self, index_price):
        """Sets the index_price of this FuturesTicker.

        Index price  # noqa: E501

        :param index_price: The index_price of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._index_price = index_price

    @property
    def quanto_base_rate(self):
        """Gets the quanto_base_rate of this FuturesTicker.  # noqa: E501

        Exchange rate of base currency and settlement currency in Quanto contract. Does not exists in contracts of other types  # noqa: E501

        :return: The quanto_base_rate of this FuturesTicker.  # noqa: E501
        :rtype: str
        """
        return self._quanto_base_rate

    @quanto_base_rate.setter
    def quanto_base_rate(self, quanto_base_rate):
        """Sets the quanto_base_rate of this FuturesTicker.

        Exchange rate of base currency and settlement currency in Quanto contract. Does not exists in contracts of other types  # noqa: E501

        :param quanto_base_rate: The quanto_base_rate of this FuturesTicker.  # noqa: E501
        :type: str
        """

        self._quanto_base_rate = quanto_base_rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FuturesTicker):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FuturesTicker):
            return True

        return self.to_dict() != other.to_dict()
